<TS language="ar" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>انشأ عنوان جديد</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;جديد</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>قم بنسخ القوانين المختارة لحافظة النظام</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;نسخ</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>حذف العنوان المحدد من القائمة</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;أمسح</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>نسخ &amp;الوصف</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>تعديل</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>وصف</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>عنوان</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(لا وصف)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>حوار جملة السر</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>ادخل كلمة المرور</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>كلمة مرور جديدة</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>ادخل كلمة المرور الجديدة مرة أخرى</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>أدخل عبارة مرور جديدة إلى المحفظة. الرجاء استخدام عبارة مرور تتكون من10 حروف عشوائية على الاقل, أو أكثر من 7 كلمات</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>تشفير المحفظة</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>هذه العملية تحتاج كلمة مرور محفظتك لفتحها</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>إفتح المحفظة</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>تغيير كلمة المرور</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>تأكيد تشفير المحفظة</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>هل أنت متأكد من رغبتك في تشفير محفظتك ؟</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>محفظة مشفرة</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>هام: أي نسخة إحتياطية سابقة  قمت بها لمحفظتك يجب استبدالها  بأخرى حديثة، مشفرة. لأسباب أمنية، النسخ الاحتياطية السابقة لملفات المحفظة الغير مشفرة تصبح عديمة الفائدة مع بداية استخدام المحفظة المشفرة الجديدة.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>فشل تشفير المحفظة</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>فشل تشفير المحفظة بسبب خطأ داخلي. لم يتم تشفير محفظتك.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>كلمتي المرور ليستا متطابقتان</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>فشل فتح المحفظة</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>كلمة المرور التي تم إدخالها لفك تشفير المحفظة غير صحيحة.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>لقد تم تغير عبارة مرور المحفظة بنجاح</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>تحذير: مفتاح الحروف الكبيرة مفعل</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>محفظة</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;نظرة عامة</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>إظهار نظرة عامة على المحفظة</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;ارسل</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;استقبل</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>تصفح سجل المعاملات</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>الخروج من التطبيق</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;خيارات ...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;عرض / اخفاء</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;تشفير المحفظة</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;تغيير كلمة المرور</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>تغيير كلمة المرور المستخدمة لتشفير المحفظة</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>التوقيع و الرسائل</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;التحقق من الرسالة...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;نافذة المعالجة</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>إفتح وحدة التصحيح و التشخيص</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;ملف</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;الاعدادات</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;مساعدة</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>محدث</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>اللحاق بالركب ...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>المعاملات  المرسلة</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>المعاملات الواردة</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>المحفظة &lt;b&gt;مشفرة&lt;/b&gt; و &lt;b&gt;مقفلة&lt;/b&gt; حاليا</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>الكمية :</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>بايت</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>القيمة :</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>رسوم :</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>بعد الرسوم :</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>تعديل :</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>مبلغ</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاريخ</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>تأكيدات</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>تأكيد</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>  انسخ عنوان</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation> انسخ التسمية</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>نسخ الكمية</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>نسخ رقم العملية</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>نسخ الكمية </translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>نسخ الرسوم</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>نسخ بعد الرسوم</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>نسخ التعديل</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>نعم</translation>
    </message>
    <message>
        <source>no</source>
        <translation>لا</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(لا وصف)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(تغير)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>عدل العنوان</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;وصف</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;العنوان</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>عنوان أستلام جديد</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>عنوان إرسال جديد</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>تعديل عنوان الأستلام</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>تعديل عنوان الارسال</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>هدا العنوان "%1" موجود مسبقا في دفتر العناوين</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation> يمكن فتح المحفظة.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>فشل توليد مفتاح جديد.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>خيارات ...</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;الرئيسي</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;الشبكة</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;المنفذ:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>منفذ البروكسي (مثلا 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>نافذه</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;عرض</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>واجهة المستخدم &amp;اللغة:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>تم</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>الغاء</translation>
    </message>
    <message>
        <source>default</source>
        <translation>الافتراضي</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>عنوان الوكيل توفيره غير صالح.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>نمودج</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>متوفر</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>غير ناضجة</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>المجموع:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>رصيدك الكلي الحالي</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>غير معروف</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>نسخه العميل</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>المعلومات</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>وقت البدء</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>عدد الاتصالات</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>الفتح</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;مسح</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;حركة مرور الشبكة</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>المجاميع</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>داخل:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>خارج:</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>استخدم اسهم الاعلى و الاسفل للتنقل بين السجلات و &lt;b&gt;Ctrl-L&lt;/b&gt;  لمسح الشاشة</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 بايت</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 كيلو بايت</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 ميقا بايت</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 قيقا بايت</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>إرسال Coins</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>اختيار تلقائيا</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>الرصيد غير كافي!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>الكمية :</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>بايت</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>القيمة :</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>رسوم :</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>بعد الرسوم :</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>إرسال إلى عدة مستلمين في وقت واحد</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>أضافة &amp;مستلم</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>مسح الكل</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>تأكيد الإرسال</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;ارسال</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>نسخ الكمية </translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>نسخ الكمية</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>نسخ الرسوم</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>نسخ بعد الرسوم</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>نسخ التعديل</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>تأكيد الإرسال Coins</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>المبلغ المدفوع يجب ان يكون اكبر من 0</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>القيمة تتجاوز رصيدك</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>المجموع يتجاوز رصيدك عندما يتم اضافة %1 رسوم العملية</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(لا وصف)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;القيمة</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>ادفع &amp;الى :</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>الرسائل</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;وصف :</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>انسخ العنوان من لوحة المفاتيح</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>إدخال تسمية لهذا العنوان لإضافته إلى دفتر العناوين الخاص بك</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;توقيع الرسالة</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>انسخ العنوان من لوحة المفاتيح</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>ادخل الرسالة التي تريد توقيعها هنا</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>توقيع $الرسالة</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>مسح الكل</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;تحقق رسالة</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>اضغط  "توقيع الرسالة" لتوليد التوقيع</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>العنوان المدخل غير صالح</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>الرجاء التأكد من العنوان والمحاولة مرة اخرى</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>العنوان المدخل لا يشير الى مفتاح</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>تم الغاء عملية فتح المحفظة</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>المفتاح الخاص للعنوان المدخل غير موجود.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>فشل توقيع الرسالة.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>الرسالة موقعة.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>فضلا تاكد من التوقيع وحاول مرة اخرى</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>فشلت عملية التأكد من الرسالة.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>تم تأكيد الرسالة.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>مفتوح حتى %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1 غير متواجد</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>غير مؤكدة/%1</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>تأكيد %1</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>الحالة.</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>,  لم يتم حتى الآن البث بنجاح</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاريخ</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <source>From</source>
        <translation>من</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>غير معروف</translation>
    </message>
    <message>
        <source>To</source>
        <translation>الى</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>عنوانه</translation>
    </message>
    <message>
        <source>label</source>
        <translation>علامة</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>غير مقبولة</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>دين</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>رسوم المعاملة</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>رسالة </translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>تعليق</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>مبلغ</translation>
    </message>
    <message>
        <source>true</source>
        <translation>صحيح</translation>
    </message>
    <message>
        <source>false</source>
        <translation>خاطئ</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>يبين هذا الجزء وصفا مفصلا لهده المعاملة</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>تاريخ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>النوع</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>مفتوح حتى %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>غير متصل</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>يتعارض</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>ولدت ولكن لم تقبل</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>استقبل مع</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>استقبل من</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>أرسل إلى</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>دفع لنفسك</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>غير متوفر</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>حالة المعاملة. تحوم حول هذا الحقل لعرض عدد  التأكيدات.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>التاريخ والوقت الذي تم فيه تلقي المعاملة.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>نوع المعاملات</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>المبلغ الذي أزيل أو أضيف الى الرصيد</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>اليوم</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>هدا الاسبوع</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>هدا الشهر</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>الشهر الماضي</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>هدا العام</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>المدى...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>استقبل مع</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>أرسل إلى</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>إليك</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>اخرى</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>الحد الأدنى</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>  انسخ عنوان</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation> انسخ التسمية</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>نسخ الكمية</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>نسخ رقم العملية</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>عدل الوصف</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>عرض تفاصيل المعاملة</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>تأكيد</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاريخ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>وصف</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>عنوان</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>العنوان</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>المدى:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>الى</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>فشل في الاستماع على أي منفذ. استخدام الاستماع = 0 إذا كنت تريد هذا.</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>عنوان البروكسي غير صحيح : '%s'</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>تحميل العنوان</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>اموال غير كافية</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>تحميل مؤشر الكتلة</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>تحميل المحفظه</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>لايمكن كتابة العنوان الافتراضي</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>إعادة مسح</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>انتهاء التحميل</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
</context>
</TS>